@@ -2,9 +2,9 @@ import os
 
 import torch
 from torch import Tensor
-from torch.nn import Module, Linear, LayerNorm, Embedding
+from torch.nn import Module
 
-from ..modules import TransformerEncoder, TransformerDecoder, TanhHead
+from ..modules import Linear, LayerNorm, Embedding, TransformerEncoder, TransformerDecoder, TanhHead
 from ..utils import transposed_cat
 
 
