@@ -1,14 +1,9 @@
 import os
-import logging
-
 import torch
 
 from ..modules import TransformerEncoder, MaskEmbeddings
 
 
-logger = logging.getLogger(__name__)
-
-
 class BertModel(torch.nn.Module):
     def __init__(
             self, vocab_size: int, dim: int, padding_idx: int,
