@@ -1,4 +1,5 @@
-from .modules import TanhHead
+from .base_modules import Linear, Embedding, LayerNorm
+from .heads import TanhHead
 from .embeddings import Embeddings, MaskEmbeddings, EmbeddingsWithTokenTypes
 from .transformer_encoder import TransformerEncoder
 from .transformer_decoder import TransformerDecoder
