@@ -28,9 +28,7 @@ class SocketConnection:
     def read_buffer(self) -> bytes:
         response = bytes()
         while True:
-            logger.debug('Reading buffer')
             buffer = self.connection.recv(self.message_size)
-            logger.debug('Received piece of data')
             if not buffer:
                 raise ConnectionError('No response, other side probably died')
             response += buffer
